@@ -1,5 +1,5 @@
 package Yancy;
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 # ABSTRACT: A simple CMS for administrating data
 
 #pod =head1 SYNOPSIS
@@ -335,6 +335,32 @@ our $VERSION = '0.018';
 #pod
 #pod =over
 #pod
+#pod =item title
+#pod
+#pod A friendly title for the collection
+#pod
+#pod =item description
+#pod
+#pod A description of the collection. Markdown will be parsed into HTML.
+#pod
+#pod You can use the C<trim> and C<unindent> functions from L<Mojo::Util> to
+#pod allow indenting your collection description:
+#pod
+#pod     use Mojolicious::Lite;
+#pod     use Mojo::Util qw( unindent trim );
+#pod     plugin Yancy => {
+#pod         collections => {
+#pod             employees => {
+#pod                 description => unindent( trim q{
+#pod                     The employees of Planet Express.
+#pod
+#pod                     * [View the employee health plan](/decapod-life)
+#pod                     * [Latest Good News](/news)
+#pod                 } ),
+#pod             },
+#pod         },
+#pod     };
+#pod
 #pod =item x-hidden
 #pod
 #pod If this is true, the collection will be hidden from the list in the Yancy
@@ -396,6 +422,14 @@ our $VERSION = '0.018';
 #pod
 #pod =over
 #pod
+#pod =item title
+#pod
+#pod A friendly title for the field
+#pod
+#pod =item description
+#pod
+#pod A description of the field. Markdown will be parsed into HTML.
+#pod
 #pod =item x-hidden
 #pod
 #pod If true, thie field will be hidden from the rich editing form.
@@ -503,7 +537,7 @@ Yancy - A simple CMS for administrating data
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -834,6 +868,32 @@ to control how it is treated by Yancy.
 
 =over
 
+=item title
+
+A friendly title for the collection
+
+=item description
+
+A description of the collection. Markdown will be parsed into HTML.
+
+You can use the C<trim> and C<unindent> functions from L<Mojo::Util> to
+allow indenting your collection description:
+
+    use Mojolicious::Lite;
+    use Mojo::Util qw( unindent trim );
+    plugin Yancy => {
+        collections => {
+            employees => {
+                description => unindent( trim q{
+                    The employees of Planet Express.
+
+                    * [View the employee health plan](/decapod-life)
+                    * [Latest Good News](/news)
+                } ),
+            },
+        },
+    };
+
 =item x-hidden
 
 If this is true, the collection will be hidden from the list in the Yancy
@@ -895,6 +955,14 @@ to control how it is treated by Yancy.
 
 =over
 
+=item title
+
+A friendly title for the field
+
+=item description
+
+A description of the field. Markdown will be parsed into HTML.
+
 =item x-hidden
 
 If true, thie field will be hidden from the rich editing form.
