@@ -1,5 +1,5 @@
 package Yancy::Plugin::Auth::Basic;
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 # ABSTRACT: A simple auth module for a site
 
 #pod =encoding utf8
@@ -20,14 +20,14 @@ our $VERSION = '0.018';
 #pod             },
 #pod         },
 #pod     };
-#pod     plugin 'Auth::Basic' => {
+#pod     app->yancy->plugin( 'Auth::Basic' => {
 #pod         collection => 'users',
 #pod         username_field => 'username',
 #pod         password_field => 'password', # default
 #pod         password_digest => {
 #pod             type => 'SHA-1',
 #pod         },
-#pod     };
+#pod     } );
 #pod
 #pod     # yancy.conf
 #pod     {
@@ -94,10 +94,10 @@ our $VERSION = '0.018';
 #pod             },
 #pod         },
 #pod     };
-#pod     plugin 'Auth::Basic' => {
+#pod     app->yancy->plugin( 'Auth::Basic' => {
 #pod         collection => 'users',
 #pod         password_digest => { type => 'SHA-1' },
-#pod     };
+#pod     } );
 #pod
 #pod =item password_field
 #pod
@@ -133,13 +133,13 @@ our $VERSION = '0.018';
 #pod
 #pod     # Use Bcrypt for passwords
 #pod     # Install the Digest::Bcrypt module first!
-#pod     plugin 'Auth::Basic' => {
+#pod     app->yancy->plugin( 'Auth::Basic' => {
 #pod         password_digest => {
 #pod             type => 'Bcrypt',
 #pod             cost => 12,
 #pod             salt => 'abcdefgh♥stuff',
 #pod         },
-#pod     };
+#pod     } );
 #pod
 #pod =item route
 #pod
@@ -166,6 +166,11 @@ our $VERSION = '0.018';
 #pod This template displays an error message that the user is not authorized
 #pod to view this page. This most-often appears when the user is not logged in.
 #pod
+#pod =item layouts/yancy/auth.html.ep
+#pod
+#pod The layout that Yancy uses when displaying the login form, the
+#pod unauthorized error message, and other auth-related pages.
+#pod
 #pod =back
 #pod
 #pod =head1 FILTERS
@@ -335,7 +340,9 @@ sub register {
 
 sub _get_login {
     my ( $c ) = @_;
-    return $c->render( 'yancy/auth/login' );
+    return $c->render( 'yancy/auth/login',
+        return_to => $c->req->headers->referrer,
+    );
 }
 
 sub _post_login {
@@ -349,7 +356,12 @@ sub _post_login {
         return $c->rendered( 303 );
     }
     $c->flash( error => 'Username or password incorrect' );
-    return $c->render( 'yancy/auth/login', status => 400 );
+    return $c->render( 'yancy/auth/login',
+        status => 400,
+        user => $user,
+        return_to => $c->req->param( 'return_to' ),
+        login_failed => 1,
+    );
 }
 
 sub _get_logout {
@@ -369,7 +381,7 @@ Yancy::Plugin::Auth::Basic - A simple auth module for a site
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 DESCRIPTION
 
@@ -395,14 +407,14 @@ then authorized to use the administration application and API.
             },
         },
     };
-    plugin 'Auth::Basic' => {
+    app->yancy->plugin( 'Auth::Basic' => {
         collection => 'users',
         username_field => 'username',
         password_field => 'password', # default
         password_digest => {
             type => 'SHA-1',
         },
-    };
+    } );
 
     # yancy.conf
     {
@@ -462,10 +474,10 @@ primary key, we don't need to provide a C<username_field>.
             },
         },
     };
-    plugin 'Auth::Basic' => {
+    app->yancy->plugin( 'Auth::Basic' => {
         collection => 'users',
         password_digest => { type => 'SHA-1' },
-    };
+    } );
 
 =item password_field
 
@@ -501,13 +513,13 @@ Not all Digest types require additional configuration.
 
     # Use Bcrypt for passwords
     # Install the Digest::Bcrypt module first!
-    plugin 'Auth::Basic' => {
+    app->yancy->plugin( 'Auth::Basic' => {
         password_digest => {
             type => 'Bcrypt',
             cost => 12,
             salt => 'abcdefgh♥stuff',
         },
-    };
+    } );
 
 =item route
 
@@ -534,6 +546,11 @@ url_for 'yancy.check_login' >>
 This template displays an error message that the user is not authorized
 to view this page. This most-often appears when the user is not logged in.
 
+=item layouts/yancy/auth.html.ep
+
+The layout that Yancy uses when displaying the login form, the
+unauthorized error message, and other auth-related pages.
+
 =back
 
 =head1 FILTERS
@@ -629,16 +646,23 @@ the same terms as the Perl 5 programming language system itself.
 
 __DATA__
 @@ yancy/auth/login.html.ep
-% layout 'yancy';
+% layout 'yancy/auth';
 <main id="app" class="container-fluid" style="margin-top: 10px">
     <div class="row justify-content-md-center">
         <div class="col-md-4">
             <h1>Login</h1>
+            % if ( stash 'login_failed' ) {
+            <div class="login-error alert alert-danger" role="alert">
+              Login failed: User or password incorrect!
+            </div>
+            % }
             <form action="<%= url_for 'yancy.check_login' %>" method="POST">
-                <input type="hidden" name="return_to" value="<%= $c->req->headers->referrer %>" />
+                <input type="hidden" name="return_to" value="<%= stash 'return_to' %>" />
                 <div class="form-group">
                     <label for="yancy-username">Username</label>
-                    <input class="form-control" id="yancy-username" name="username" placeholder="username">
+                    <input class="form-control" id="yancy-username" name="username"
+                        placeholder="username" value="<%= stash 'user' %>"
+                    >
                 </div>
                 <div class="form-group">
                     <label for="yancy-password">Password</label>
@@ -651,7 +675,7 @@ __DATA__
 </main>
 
 @@ yancy/auth/unauthorized.html.ep
-% layout 'yancy';
+% layout 'yancy/auth';
 <main class="container-fluid" style="margin-top: 10px">
     <div class="row">
         <div class="col">
