@@ -3,7 +3,7 @@ package Local::Test;
 =head1 SYNOPSIS
 
     use Test::More;
-    use Local::Test qw( test_backend );
+    use Local::Test qw( test_backend init_backend );
 
     subtest 'test my backend' => \&test_backend, $backend_object,
         collection => { ... },
@@ -25,7 +25,91 @@ use Mojo::Base '-strict';
 use Exporter 'import';
 use Test::Builder;
 use Test::More ();
-our @EXPORT_OK = qw( test_backend );
+use Yancy::Util qw( load_backend );
+use Yancy::Backend::Test;
+our @EXPORT_OK = qw( test_backend init_backend );
+
+=sub init_backend
+
+    my ( $backend, $url ) = init_backend( @items );
+
+Initialize a backend for testing with the given items. This routine will
+check the C<TEST_YANCY_BACKEND> environment variable for connection
+details, if any. Otherwise, it will create a L<Yancy::Backend::Test>
+object for mock testing.
+
+=cut
+
+my %to_delete;
+my $backend;
+sub init_backend {
+    my ( $collections, %items ) = @_;
+    my %out_items;
+    my $backend_url = $ENV{TEST_YANCY_BACKEND} || 'test://localhost';
+    $backend = load_backend( $backend_url, $collections );
+    for my $collection ( keys %items ) {
+        for my $item ( @{ $items{ $collection } } ) {
+            my $item = $backend->create( $collection, $item );
+            push @{ $out_items{ $collection } }, $item;
+            push @{ $to_delete{ $collection } },
+                $item->{ $collections->{ $collection }{ 'x-id-field' } // 'id' };
+        }
+    }
+    return ( $backend_url, $backend, %out_items );
+}
+
+END {
+    for my $coll ( keys %to_delete ) {
+        $backend->delete( $coll, $_ ) for @{ $to_delete{ $coll } };
+    }
+};
+
+# This is only for when the Test backend is being used and is
+# ignored when TEST_YANCY_BACKEND is set to something else
+%Yancy::Backend::Test::SCHEMA = (
+    people => {
+        type => 'object',
+        required => [qw( name )],
+        properties => {
+            id => {
+                'x-order' => 1,
+                type => 'integer',
+            },
+            name => {
+                'x-order' => 2,
+                type => 'string',
+            },
+            email => {
+                'x-order' => 3,
+                type => [ 'string', 'null' ],
+            },
+        },
+    },
+    user => {
+        type => 'object',
+        'x-id-field' => 'username',
+        required => [qw( username email password )],
+        properties => {
+            username => {
+                'x-order' => 1,
+                type => 'string',
+            },
+            email => {
+                'x-order' => 2,
+                type => 'string',
+            },
+            password => {
+                'x-order' => 3,
+                type => 'string',
+            },
+            access => {
+                'x-order' => 4,
+                type => 'string',
+                enum => [qw( user moderator admin )],
+            },
+        },
+    },
+);
 
 =sub test_backend
 
